# Holo Video Object for React Three Fiber

holo-video-object-r3f is a library for holographic video playback in React Three Fiber.

## Installation

`npm i three @MixedRealityCaptureStudios/holo-video-object-r3f`

## Quick Start

```tsx
import React, { useState } from 'react';
import { HoloVideoObject } from '@MixedRealityCaptureStudios/holo-video-object-r3f';

const App = () => {
  const [playing, setPlaying] = useState(false);

  return (
    <>
      <button onClick={() => { setPlaying(true); }}>
        Play
      </button>

      <Canvas>
        <HoloVideoObject
          path="scene.hcap"
          playing={playing}
        />
      </Canvas>
    </>
  );
}

```

## Example scene
A comprehensive example scene can be found in the `mrcs-examples` package.

## Props

| Name | Type | Default | Remarks |
| --- | --- | --- | --- |
| path | string | - | The path to an hcap file encoded for web. |
| playing | boolean | false | Controls whether the HVO is playing. A user agent [may prevent](https://developer.mozilla.org/en-US/docs/Web/API/HTMLMediaElement/play#usage_notes) this prop from playing the HVO at page load unless this prop is true as a result of a user action like pressing a play button. See the quick start example above for a reference. |
| muted | boolean | false | The mute state of the HVO's audio. |
| onUpdate | (currentTime: number, totalTime: number) => void | () => {} | Callback fired when the internal HVO is updated. The callback passes the current and total time of the capture. The example project uses this callback to synchronize a playhead. |
| useFileCoordinates | boolean | false | Controls whether or not to adjust the scale of the HVO. Setting this prop to true will use the internal scale of the capture. Setting this prop to false will scale the capture by `0.01`. |
| meshProps | JSX.IntrinsicElements['mesh']; | {} | The standard mesh props passed to the internal hvo |

The `ref` is forwarded to an internal HoloVideoObjectThreeJS instance.

## HoloVideoObjectThreeJS

This library is a wrapper around `holo-video-object-three`. The HoloVideoObject component handles synchronizing props to the internal three HVO. You can get a handle to the internal HVO using a ref. The full API for the three library can be found in the `@MixedRealityCaptureStudios/holo-video-object-three` package.