import React, { useRef, useState, useEffect, useImperativeHandle, } from 'react';
import * as Three from 'three';
import { useFrame, useThree } from '@react-three/fiber';
import { HoloVideoObjectThreeJS } from '@MixedRealityCaptureStudios/holo-video-object-three';
const tuple = (...args) => args;
const multiply = ([ax, ay, az], [bx, by, bz]) => ([ax * bx, ay * by, az * bz]);
const getScale = (scale) => {
    if (typeof scale === 'number') {
        return tuple(scale, scale, scale);
    }
    if (scale instanceof Three.Vector3) {
        return tuple(scale.x, scale.y, scale.z);
    }
    return scale ?? tuple(1, 1, 1);
};
export const HoloVideoObject = React.forwardRef((props, ref) => {
    const { gl } = useThree();
    const [hvoMesh, setHvoMesh] = useState();
    const hvoRef = useRef();
    useImperativeHandle(ref, () => hvoRef.current);
    const { path, playing = false, muted = false, useFileCoordinates = false, onUpdate = () => { }, meshProps, } = props;
    useEffect(() => {
        if (!hvoRef.current) {
            return;
        }
        if (playing) {
            hvoRef.current.play();
        }
        else {
            hvoRef.current.pause();
        }
    }, [playing, hvoRef.current?.hvo.id]);
    useEffect(() => {
        if (!hvoRef.current) {
            return;
        }
        hvoRef.current.setAudioEnabled(!muted);
    }, [muted]);
    useFrame(() => {
        if (!hvoRef.current) {
            return;
        }
        hvoRef.current.update();
        const currentTime = hvoRef.current.hvo.lastVideoTime;
        const videoDuration = hvoRef.current.hvo?.videoElement?.duration ?? 0;
        const adjustedDuration = Number.isNaN(videoDuration) ? 0 : videoDuration;
        const totalTime = adjustedDuration * 1000;
        onUpdate(currentTime, totalTime);
    });
    useEffect(() => {
        const hvo = new HoloVideoObjectThreeJS(gl, (mesh) => { setHvoMesh(mesh); });
        hvo.open(path, { autoloop: true, audioEnabled: true, keepAllMeshesInMemory: true });
        hvoRef.current = hvo;
        return () => { hvoRef.current.close(); };
    }, [props.path]);
    const scale = getScale(meshProps.scale);
    const centimetersToMeters = tuple(0.01, 0.01, 0.01);
    const adjustedScale = useFileCoordinates
        ? scale
        : multiply(scale, centimetersToMeters);
    const adjustedMeshProps = {
        position: tuple(0, 0, 0),
        ...meshProps,
        scale: adjustedScale,
    };
    return hvoMesh && (React.createElement("mesh", { ...adjustedMeshProps, castShadow: true, receiveShadow: true, geometry: hvoMesh.geometry, material: hvoMesh.material }));
});
//# sourceMappingURL=HoloVideoObject.js.map