// CONFIDENTIAL.  Distribution Only to Partners Under Nondisclosure. Microsoft makes no warranties, express or implied.
// Copyright © Microsoft. All rights reserved.
import { HoloVideoObject, ErrorStates, States } from "@MixedRealityCaptureStudios/holo-video-object";
import { HoloVideoObjectProxy } from "@MixedRealityCaptureStudios/holo-video-object/dist/src/holoVideoObjectProxy";
import { HoloVideoCreateOptionsWebGL } from "@MixedRealityCaptureStudios/holo-video-object/dist/src/holoVideoWebGLBackend";
import { HoloVideoThreeBackend, HvoMesh } from "@MixedRealityCaptureStudios/holo-video-object/dist/src/holoVideoThreeBackend";
import * as Three from "three";

type HoloVideoCreateOptionsThree = HoloVideoCreateOptionsWebGL & {
    /* @internal */
    _renderer?: Three.WebGLRenderer;
};

export class HoloVideoObjectThreeJS extends HoloVideoObjectProxy {
    mesh: HvoMesh;

    protected _createHoloVideoObject(
        createOptions: HoloVideoCreateOptionsThree,
        updateCurrentFrameCallback?: (frame: number) => void,
        errorCallback?: (type: ErrorStates, info?: Error | MediaError) => void
    ): HoloVideoObject {
        return new HoloVideoObject(new HoloVideoThreeBackend(createOptions._renderer), createOptions, errorCallback);
    }

    /**
     * Creates a new HoloVideoObjectThreeJS instance
     * @param {Three.WebGLRenderer} renderer - WebGLRenderer that will be used to render the capture.
     * @param {HoloVideoObjectThreeJS~openCallback} - Callback invoked when initial loading is complete.
     * @param {Object} createOptions - Optional collection of options that permanently affect behavior of this HoloVideoObjectThreeJS instance.
     * @param {boolean} createOptions.disableAsyncDecode - Disables asynchronous video decoding path which may result in improved audio sync but incurs a performance penalty. This is the only decoding path available in WebGL1 environments.
     * @param {number} createOptions.numAsyncFrames - Controls how many asynchronous frames are buffered in WebGL2 async. decode path resulting in 'numAsyncFrames' - 1 frames of latency. The default value is 3.
     * @param {boolean} createOptions.disableTransformFeedback - Disables the plugin's default WebGL2 geometry update path while still allowing WebGL2 texture updates. Default is false.
     * @param {function} - Callback invoked when currentFrame is updated
     * @param {HoloVideoObject~errorCallback} - Callback invoked when unexpected error condition is encountered, see {@link HoloVideoObject#ErrorStates} for list of possible conditions.
     */
    constructor(
        renderer: Three.WebGLRenderer,
        callback: (mesh: HvoMesh) => void,
        createOptions?: HoloVideoCreateOptionsThree,
        updateCurrentFrameCallback?: (frame: number) => void,
        errorCallback?: (type: ErrorStates, info?: Error | MediaError) => void
    ) {
        super(
            () => void 0,
            {
                _renderer: renderer,
                outputLinearTextures: renderer.outputEncoding === Three.sRGBEncoding,
                gl: renderer.getContext(),
                ...createOptions,
            },
            updateCurrentFrameCallback,
            errorCallback
        );

        const curOnLoaded = this.hvo.onLoaded.bind(this.hvo);

        this.hvo.onLoaded = (fileInfo) => {
            curOnLoaded(fileInfo);

            this.mesh = (this.hvo.getGraphicBackend() as HoloVideoThreeBackend).getMesh();

            callback(this.mesh);
        };
    }
}

export { States };
