import { States } from "./holovideoobject";
export class HoloVideoObjectProxy {
    onEndOfStream;
    hvo;
    state;
    fileInfo;
    _hvoOnEndOfStream(hvo) {
        if (this.onEndOfStream) {
            this.onEndOfStream(this);
        }
    }
    constructor(callback, createOptions, updateCurrentFrameCallback, errorCallback) {
        const hvo = this._createHoloVideoObject(createOptions, updateCurrentFrameCallback, errorCallback);
        this.hvo = hvo;
        hvo.onEndOfStream = this._hvoOnEndOfStream.bind(this);
        hvo.onUpdateCurrentFrame = updateCurrentFrameCallback;
        hvo.onLoaded = (fileInfo) => {
            this.fileInfo = fileInfo;
            this.state = this.hvo.state;
            callback();
        };
    }
    open(url, options) {
        if (this.state > States.Empty) {
            this.close();
        }
        this.hvo.open(url, options);
        this.state = this.hvo.state;
    }
    update() {
        if (this.hvo) {
            this.state = this.hvo.state;
        }
        this.hvo.update();
    }
    rewind() {
        this.hvo.rewind();
    }
    seekToTime(seekTime, displayImmediately) {
        this.hvo.seekToTime(seekTime, displayImmediately);
    }
    play() {
        if (this.hvo.state == States.Opening) {
            this.hvo.forceLoad();
        }
        else if (this.hvo.state >= States.Opened && this.hvo.state != States.Playing) {
            this.hvo.play();
        }
    }
    close() {
        this.hvo.close();
    }
    pause() {
        this.hvo.pause();
    }
    setLogLevel(level) {
        this.hvo.logLevel = level;
    }
    setAudioEnabled(enabled) {
        this.hvo.setAudioEnabled(enabled);
    }
    audioEnabled() {
        return this.hvo.audioEnabled();
    }
    setAudioVolume(volume) {
        this.hvo.setAudioVolume(volume);
    }
    setAutoLooping(loop) {
        this.hvo.setAutoLooping(loop);
    }
}
//# sourceMappingURL=holoVideoObjectProxy.js.map