import { HoloVideoWebGLBackend } from "./holoVideoWebGLBackend";
import * as Three from "three";
export class HoloVideoThreeBackend extends HoloVideoWebGLBackend {
    _renderer;
    _unlitMaterial;
    _litMaterial;
    mesh;
    bufferGeometry;
    constructor(renderer) {
        super();
        this._renderer = renderer;
        this._unlitMaterial = new Three.MeshBasicMaterial({ map: null, transparent: false, side: Three.DoubleSide });
        this._litMaterial = new Three.MeshPhysicalMaterial({ map: null, transparent: false, side: Three.FrontSide, roughness: 1, metalness: 0 });
    }
    release() {
        super.release();
        this._unlitMaterial.dispose();
        this._litMaterial.dispose();
    }
    onLoaded(fileInfo) {
        super.onLoaded(fileInfo);
        const useNormals = fileInfo.haveNormals;
        var indexType = fileInfo.indicesComponentType;
        if (this.mesh) {
            var indexAt = this.mesh.geometry.getIndex();
            var normalAt = this.mesh.geometry.getAttribute("normal");
            var haveNormals = normalAt != undefined;
            if (indexAt.type != indexType || haveNormals != useNormals) {
                this.mesh = null;
            }
            else {
                var material = useNormals ? this._litMaterial : this._unlitMaterial;
                material.map = this.mesh.material.map;
                this.mesh.material = material;
            }
        }
        if (!this.mesh) {
            var bufferGeometry = new Three.BufferGeometry();
            bufferGeometry.boundingSphere = new Three.Sphere();
            bufferGeometry.boundingSphere.set(new Three.Vector3(), Infinity);
            bufferGeometry.boundingBox = new Three.Box3();
            bufferGeometry.boundingBox.set(new Three.Vector3(-Infinity, -Infinity, -Infinity), new Three.Vector3(+Infinity, +Infinity, +Infinity));
            const gl = this.gl;
            var posBuf = this.clientBuffers.posBuf;
            const revision = Number(Three.REVISION);
            var posAttr = revision >= 120 ? new Three.GLBufferAttribute(posBuf, gl.FLOAT, 3, 0) : new Three.GLBufferAttribute(gl, posBuf, gl.FLOAT, 3, 0);
            bufferGeometry.setAttribute("position", posAttr);
            if (this.clientBuffers.norBuf) {
                var norAttr = revision >= 120
                    ? new Three.GLBufferAttribute(this.clientBuffers.norBuf, gl.FLOAT, 3, 0)
                    : new Three.GLBufferAttribute(gl, this.clientBuffers.norBuf, gl.FLOAT, 3, 0);
                bufferGeometry.setAttribute("normal", norAttr);
            }
            var uvBuf = this.clientBuffers.uvBuf;
            var uvAttr = revision >= 120 ? new Three.GLBufferAttribute(uvBuf, gl.UNSIGNED_SHORT, 2, 0) : new Three.GLBufferAttribute(gl, uvBuf, gl.UNSIGNED_SHORT, 2, 0);
            uvAttr.normalized = true;
            bufferGeometry.setAttribute("uv", uvAttr);
            var indexBuf = this.clientBuffers.indexBuf;
            var indAttr = revision >= 120 ? new Three.GLBufferAttribute(indexBuf, indexType, 0, 0) : new Three.GLBufferAttribute(gl, indexBuf, indexType, 0, 0);
            bufferGeometry.setIndex(indAttr);
            var texture = new Three.Texture();
            var texProps = this._renderer.properties.get(texture);
            texProps.__webglTexture = this.clientBuffers.tex;
            var material = useNormals ? this._litMaterial : this._unlitMaterial;
            material.map = texture;
            var mesh = new Three.Mesh(bufferGeometry, material);
            mesh.scale.x = 0.001;
            mesh.scale.y = 0.001;
            mesh.scale.z = 0.001;
            this.mesh = mesh;
            this.bufferGeometry = bufferGeometry;
        }
    }
    onUpdate(updated, currentFrameInfo) {
        if (!updated) {
            return;
        }
        var min = currentFrameInfo.bboxMin;
        var max = currentFrameInfo.bboxMax;
        var bufferGeometry = this.bufferGeometry;
        bufferGeometry.boundingBox.min.x = min[0];
        bufferGeometry.boundingBox.min.y = min[1];
        bufferGeometry.boundingBox.min.z = min[2];
        bufferGeometry.boundingBox.max.x = max[0];
        bufferGeometry.boundingBox.max.y = max[1];
        bufferGeometry.boundingBox.max.z = max[2];
        bufferGeometry.boundingBox.getCenter(bufferGeometry.boundingSphere.center);
        var maxSide = Math.max(max[0] - min[0], max[1] - min[1], max[2] - min[2]);
        bufferGeometry.boundingSphere.radius = maxSide * 0.5;
        bufferGeometry.index.count = currentFrameInfo.primCount;
    }
    onClose() {
        super.onClose();
        if (this.bufferGeometry) {
            this.bufferGeometry.index.count = 0;
        }
    }
    getMesh() {
        return this.mesh;
    }
}
//# sourceMappingURL=holoVideoThreeBackend.js.map