import { IHoloVideoGraphicBackend, IHoloVideoHost, HoloVideoCreateOptions, HoloVideoBrowserInfo, FileInfo, OpenOptions, MeshState, FrameInfo } from "./holoVideoInterface";
export declare type HoloVideoCreateOptionsWebGL = HoloVideoCreateOptions & {
    disableAsyncDecode?: boolean;
    numAsyncFrames?: number;
    disableTransformFeedback?: boolean;
    gl?: WebGLRenderingContext | WebGL2RenderingContext;
};
declare type Program = WebGLProgram & {
    havePrevPosLoc: WebGLUniformLocation;
    havePrevPrevPosLoc: WebGLUniformLocation;
    decodeMinLoc: WebGLUniformLocation;
    decodeMaxLoc: WebGLUniformLocation;
    inQuantizedLoc: number;
    prevPosLoc: number;
    prevPrevPosLoc: number;
    inOctNormalLoc: number;
    vertexAttribLoc: number;
    textureSamplerLoc: WebGLUniformLocation;
};
declare type TexCopyProgram = Program & {
    useGammaCorrectionLoc: WebGLUniformLocation;
};
export declare class HoloVideoWebGLBackend implements IHoloVideoGraphicBackend {
    protected _host: IHoloVideoHost;
    protected _browserInfo: HoloVideoBrowserInfo;
    protected _fileInfo: FileInfo;
    protected gl: WebGLRenderingContext | WebGL2RenderingContext;
    protected createOptions: HoloVideoCreateOptionsWebGL;
    protected caps: {
        webgl2: boolean;
        badTF: boolean;
        supports32BitIndices: boolean;
    };
    protected capsStr: string;
    protected nextPbo: number;
    protected readPbo: number;
    protected readFences: WebGLSync[];
    protected outputBufferIndex: number;
    protected texCopyVerts: WebGLBuffer;
    protected textures: WebGLTexture[];
    protected texCopyShader: TexCopyProgram | null;
    protected fbo1: WebGLFramebuffer;
    protected fbo2: WebGLFramebuffer;
    protected pixelBuffers: WebGLBuffer[];
    protected octNormalsShader: Program;
    protected contextLost: boolean;
    protected outputBuffers: [WebGLBuffer, WebGLBuffer, WebGLBuffer];
    protected normalsVao: WebGLVertexArrayObject;
    protected normalsTF: WebGLTransformFeedback | null;
    protected vaos: [WebGLVertexArrayObject, WebGLVertexArrayObject, WebGLVertexArrayObject];
    protected transformFeedbacks: [WebGLTransformFeedback, WebGLTransformFeedback, WebGLTransformFeedback];
    protected tfShader: Program;
    protected deltasBuf: WebGLBuffer;
    protected watermarkPixels: Uint8Array;
    protected clientBuffers: {
        posBuf: WebGLBuffer;
        norBuf: WebGLBuffer;
        uvBuf: WebGLBuffer;
        indexBuf: WebGLBuffer;
        tex: WebGLBuffer;
    };
    initialize(logger: IHoloVideoHost, browserInfo: HoloVideoBrowserInfo, createOptions?: HoloVideoCreateOptionsWebGL): boolean;
    onBeforeLoad(openOptions: OpenOptions): void;
    onLoaded(fileInfo: FileInfo): void;
    onSeekToTimeCompleted(): void;
    onUpdate(updated: boolean, currentFrameInfo: FrameInfo): void;
    onRewind(): void;
    onClose(): void;
    release(): void;
    private _createProgram;
    private _initializeWebGLResources;
    private _deleteReadFences;
    private _releaseWebGLResources;
    private _setupTransformFeedback;
    updateMesh(meshState: MeshState, sourceBuffers: {
        indices: Uint16Array | Uint32Array;
        compressedPos: Uint16Array;
        compressedUVs: Uint16Array;
        compressedNormals: Uint8Array | Uint16Array;
        deltas: Uint8Array;
    }, updateClientBuffers: boolean, wasSeeking: boolean): boolean;
    private _getSrgbTextureFormat;
    private _copyTexture;
    updateMeshFromRawBuffers(indices?: Uint16Array | Uint32Array, positions?: Float32Array, uvs?: Uint16Array, normals?: Uint8Array | Uint16Array | Float32Array, staticDraw?: boolean): void;
    setTexture(image: HTMLImageElement): void;
    copyVideoTexture(): void;
    private _getWatermarkAsync;
    private _getWatermarkSync;
    getWatermark(currentVideo: HTMLVideoElement): [Uint8Array | null, boolean];
}
export {};
