import { IHoloVideoHost, Extensions, Accessor, Mesh, IHoloVideoGraphicBackend, HoloVideoCreateOptions, HoloVideoBrowserInfo, FileInfo, OpenOptions, MeshState, FrameInfo } from "./holoVideoInterface";
declare enum VideoStates {
    Undefined = 0,
    CanPlay = 1,
    CanPlayThrough = 2,
    Waiting = 3,
    Suspended = 4,
    Stalled = 5,
    Playing = 6
}
export declare enum ErrorStates {
    NetworkError = -1,
    VideoError = -2,
    PlaybackPrevented = -3
}
export declare enum States {
    Closed = -1,
    Empty = 0,
    Opening = 1,
    Opened = 2,
    Playing = 3,
    Paused = 4
}
declare type HvoJson = {
    buffers: {
        uri: string;
        loaded: boolean;
        arrayBufferIndex: number;
    }[];
    extensions: Extensions;
    images: {
        video: VideoElement;
        extensions: Extensions;
        uri: string;
        bufferView: number;
    }[];
    bufferViews: {
        buffer: number;
        byteLength: number;
        byteOffset: number;
        byteStride: number;
        extensions: object;
    }[];
    accessors: Accessor[];
    meshes: Mesh[];
};
declare type VideoElement = HTMLVideoElement & Partial<{
    videoElementIndex: number;
    preloaded: boolean;
    playing: boolean;
    mp4Name: string;
    canplay: () => void;
    waiting: () => void;
    canplaythrough: () => void;
    suspend: () => void;
    stalled: () => void;
}>;
export declare class HoloVideoObject implements IHoloVideoHost {
    id: number;
    state: States;
    graphicBackend: IHoloVideoGraphicBackend;
    json: HvoJson;
    suspended: boolean;
    seekingAutoPlay: boolean | undefined;
    seekingStartBufferIndex: number | undefined;
    fallbackFrameBuffer: ArrayBuffer;
    nextBufferLoadIndex: undefined | number;
    pendingBufferDownload: boolean;
    seekTargetTime: number;
    searchStartFrame: number;
    seeking: boolean;
    frameIndex: number;
    lastUpdate: number;
    lastVideoTime: number;
    currentBufferIndex: number;
    pauseAfterSeek: boolean;
    unmuteAfterSeek: boolean;
    eos: boolean;
    audioVolume: number;
    logLevel: number;
    openOptions: OpenOptions;
    createOptions: HoloVideoCreateOptions;
    urlRoot: string;
    dashPlayer: any;
    httpRequest: XMLHttpRequest;
    minBuffers: number;
    buffersLoaded: number;
    minVideos: number;
    videosLoaded: number;
    buffers: (ArrayBuffer & {
        bufferIndex: number;
    })[];
    freeArrayBuffers: number[];
    meshState: MeshState;
    lastKeyframe: number;
    contextLost: boolean;
    wasPlaying: boolean;
    onUpdateCurrentFrame: (frame: number) => void;
    errorCallback: (type: ErrorStates, info?: Error | MediaError) => void;
    onEndOfStream: (self: HoloVideoObject) => void;
    onLoaded: (fileInfo: FileInfo) => void;
    browserInfo: HoloVideoBrowserInfo;
    fileInfo: FileInfo;
    currentFrameInfo: FrameInfo;
    videoElement: VideoElement | null;
    meshFrames: Mesh[];
    nextVideoLoadIndex: number;
    videoState: VideoStates;
    lastVideoSampleIndex: number;
    pendingVideoEndEvent: boolean;
    needMeshData: boolean;
    pendingVideoEndEventWaitCount: number;
    fallbackTextureImage: HTMLImageElement & {
        loaded?: boolean;
    };
    oldVideoSampleIndex: number;
    filledFallbackFrame: boolean;
    requestKeyframe: boolean;
    static _instanceCounter: number;
    static Version: {
        Major: number;
        Minor: number;
        Patch: number;
        String: string;
    };
    private _loadJSON;
    private _loadArrayBuffer;
    private _startPlaybackIfReady;
    private _isBufferAlreadyLoaded;
    private _loadNextBuffer;
    private _setSeekTarget;
    private _frameIsKeyframe;
    private _computeSeekSearchFrame;
    private _computeSeekSearchTime;
    private _currentVideo;
    seekToTime(seekTimeMs: number, displayImmediately: boolean): void;
    private _setVideoStartTime;
    private cleanUpEventListeners;
    private videoElementInitialized;
    private _loadNextVideo;
    private _resetFreeBuffers;
    rewind(): void;
    forceLoad(): void;
    private _onVideoEnded;
    _updateMesh(updateClientBuffers?: boolean, wasSeeking?: boolean): boolean;
    private _setupMeshFrames;
    private _onJsonLoaded;
    private _getChromeVersion;
    private _getIOSVersion;
    private _getSafariVersion;
    _logDebug(message: any, force?: any): void;
    _logInfo(message: any, force?: any): void;
    _logWarning(message: any): void;
    _logError(message: any): void;
    private _onError;
    onContextLost(): void;
    onContextRestored(): void;
    constructor(backend: IHoloVideoGraphicBackend, createOptions?: HoloVideoCreateOptions, errorCallback?: (type: ErrorStates, info?: Error) => void);
    getLoadProgress(): number;
    updateToLastKeyframe(): void;
    _loadFallbackFrame(): boolean;
    update(): boolean;
    close(): void;
    pause(): void;
    setAudioVolume(volume: number): void;
    setAutoLooping(loop: boolean): void;
    setAudioEnabled(enabled: boolean): void;
    audioEnabled(): boolean;
    play(): void;
    open(gltfURL: string, options: OpenOptions): void;
    getGraphicBackend(): IHoloVideoGraphicBackend;
}
export {};
